summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/sql/tqsqlform.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/sql/tqsqlform.cpp')
-rw-r--r--tqtinterface/qt4/src/sql/tqsqlform.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/sql/tqsqlform.cpp b/tqtinterface/qt4/src/sql/tqsqlform.cpp
index ed1f935..a33c18b 100644
--- a/tqtinterface/qt4/src/sql/tqsqlform.cpp
+++ b/tqtinterface/qt4/src/sql/tqsqlform.cpp
@@ -102,7 +102,7 @@ public:
// Move the cursor to a valid record (the first record)
myCursor.next();
// Set the form's record pointer to the cursor's edit buffer (which
// tqcontains the current record's values)
myForm.setRecord( myCursor.primeUpdate() );
// Insert a field into the form that uses myEditor to edit the
@@ -200,8 +200,8 @@ void TQSqlForm::insert( TQWidget * widget, const TQString& field )
void TQSqlForm::remove( const TQString& field )
{
d->dirty = TRUE;
- if ( d->fld.tqfind( field ) != d->fld.end() )
- d->fld.remove( d->fld.tqfind( field ) );
+ if ( d->fld.find( field ) != d->fld.end() )
+ d->fld.remove( d->fld.find( field ) );
d->wgt.remove( field );
}
@@ -296,7 +296,7 @@ TQWidget * TQSqlForm::fieldToWidget( TQSqlField * field ) const
*/
TQSqlField * TQSqlForm::widgetToField( TQWidget * widget ) const
{
- if( d->map.tqcontains( widget ) )
+ if( d->map.contains( widget ) )
return d->map[widget];
else
return 0;
@@ -102,7 +102,7 @@ public:
myCursor.next();
// Set the form's record pointer to the cursor's edit buffer (which
- // tqcontains the current record's values)
+ // contains the current record's values)
myForm.setRecord( myCursor.primeUpdate() );
// Insert a field into the form that uses myEditor to edit the